# WARNING: Please don't edit this file. It was generated by Python/WinRT v3.2.0

import datetime
import sys
import types
import typing
import uuid as _uuid
from builtins import property as _property

import winrt._winrt
import winrt.system

Self = typing.TypeVar('Self')

@typing.final
class ClassicAppManager_Static(winrt._winrt.IInspectable_Static):
    # Windows.Management.Deployment.Preview.InstalledClassicAppInfo Windows.Management.Deployment.Preview.ClassicAppManager::FindInstalledApp(System.String)
    def find_installed_app(cls, app_uninstall_key: str, /) -> InstalledClassicAppInfo: ...

@typing.final
class ClassicAppManager(winrt.system.Object, metaclass=ClassicAppManager_Static):
    pass

@typing.final
class InstalledClassicAppInfo(winrt.system.Object):
    # System.String Windows.Management.Deployment.Preview.InstalledClassicAppInfo::get_DisplayName()
    @_property
    def display_name(self) -> str: ...
    # System.String Windows.Management.Deployment.Preview.InstalledClassicAppInfo::get_DisplayVersion()
    @_property
    def display_version(self) -> str: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v3.2.0

import winrt.system
from winrt._winrt_windows_management_deployment_preview import (
    ClassicAppManager,
    InstalledClassicAppInfo,
)

__all__ = [
    "ClassicAppManager",
    "InstalledClassicAppInfo",
]

